@@ -5,7 +5,7 @@ use strict;
 use 5.008003;
 no warnings 'utf8';
 
-our $VERSION = '2.005';
+our $VERSION = '2.006';
 
 use Encode                qw( decode );
 use File::Basename        qw( basename );
@@ -426,11 +426,16 @@ sub run {
                             my ( $create_table, $drop_table, $attach_databases, $detach_databases ) = (
                                 '- CREATE table', '- DROP   table', '- Attach DB', '- Detach DB'
                             );
-                            my $choices_hidden = [ undef, $create_table, $drop_table ];
+                            my $choices_hidden = [ undef ];
+                            push @$choices_hidden, $create_table if $sf->{o}{G}{create_table_ok};
+                            push @$choices_hidden, $drop_table   if $sf->{o}{G}{drop_table_ok};
                             if ( $driver eq 'SQLite' ) {
                                 push @$choices_hidden, $attach_databases;
                                 push @$choices_hidden, $detach_databases if $sf->{i}{db_attached};
                             }
+                            if ( @$choices_hidden == 0 ) {
+                                next TABLE;
+                            }
                             # Choose
                             $ENV{TC_RESET_AUTO_UP} = 0;
                             my $idx_hdn = $lyt_3->choose(
@@ -657,7 +662,7 @@ App::DBBrowser - Browse SQLite/MySQL/PostgreSQL databases and their tables inter
 
 =head1 VERSION
 
-Version 2.005
+Version 2.006
 
 =head1 DESCRIPTION
 
@@ -673,6 +678,9 @@ Matthäus Kiem <cuer2s@gmail.com>
 
 Copyright (C) 2012-2018 Matthäus Kiem.
 
+THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE
+IMPLIED WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl 5.10.0. For
 details, see the full text of the licenses in the file LICENSE.
 
