@@ -6,12 +6,13 @@ use strict;
 use 5.008003;
 no warnings 'utf8';
 
-our $VERSION = '2.005';
+our $VERSION = '2.006';
 
 use List::MoreUtils qw( any first_index );
 
-use Term::Choose       qw( choose );
-use Term::Form         qw();
+use Term::Choose     qw( choose );
+use Term::Form       qw();
+#use Term::TablePrint qw(print_table);
 
 use if $^O eq 'MSWin32', 'Win32::Console::ANSI';
 
@@ -207,12 +208,6 @@ sub on_table {
                     $cols_sql .= "*";
                 }
             }
-            #elsif ( $sql->{select_type} eq 'chosen_cols' ) {
-            #    $cols_sql .= join( ', ', @{$sql->{chosen_cols}} );
-            #}
-            #elsif ( @{$sql->{aggr_cols}} || @{$sql->{group_by_cols}} ) {
-            #    $cols_sql .= join( ', ', @{$sql->{group_by_cols}}, @{$sql->{aggr_cols}} );
-            #}
             elsif ( $sql->{select_type} eq 'chosen_cols' ) {
                 $cols_sql .= $ax->__cols_as_string( $sql, 'chosen_cols' );
             }
@@ -287,10 +282,11 @@ sub commit_sql {
     my $stmt_v = Term::Choose->new( $sf->{i}{lyt_stmt_v} );
     local $| = 1;
     print $sf->{i}{clear_screen};
-    print 'Transaction ...' . "\n" if $sf->{o}{table}{progress_bar}; ##
+    print 'DB work ...' . "\n" if $sf->{o}{table}{progress_bar}; #
     my $transaction;
     eval { $transaction = $dbh->begin_work } or do { $dbh->{AutoCommit} = 1; $transaction = 0 };
     my $rows_to_execute = [];
+    #my $row_count;
     my $stmt;
     my $stmt_type = $stmt_typeS->[-1];
     if ( $stmt_type eq 'Insert' ) {
@@ -302,6 +298,7 @@ sub commit_sql {
                             join( ', ', @{$sql->{insert_into_cols}} ),
                             join( ', ', ( '?' ) x @{$sql->{insert_into_cols}} );
         $rows_to_execute = $sql->{insert_into_args};
+        #$row_count = @$rows_to_execute;
     }
     else {
         my %map_stmt_types = (
@@ -314,6 +311,20 @@ sub commit_sql {
         $stmt .= $sql->{set_stmt}      if $sql->{set_stmt};
         $stmt .= $sql->{where_stmt}    if $sql->{where_stmt};
         $rows_to_execute->[0] = [ @{$sql->{set_args}}, @{$sql->{where_args}} ];
+        #if ( ! eval {
+        #    my $sth = $dbh->prepare( "SELECT * FROM " . $sql->{table} . ( $sql->{where_stmt} ? $sql->{where_stmt} : '' ) );
+        #    $sth->execute( @{$sql->{where_args}} );
+        #    my $col_names = $sth->{NAME};
+        #    my $all_arrayref = $sth->fetchall_arrayref;
+        #    $row_count = @$all_arrayref;
+        #    unshift @$all_arrayref, $col_names;
+        #    my $prompt_pt = "ENTER to continue\n$stmt_type - affected records:\n";
+        #    print_table( $all_arrayref, { %{$sf->{o}{table}}, prompt => $prompt_pt, max_rows => 0, table_expand => 0 } ); #
+        #    die "'row_count' undefined" if ! defined $row_count;
+        #    1 }
+        #) {
+        #    $ax->print_error_message( "$@Fetching info: affected records ...\n", $stmt_type );
+        #}
     }
     if ( $transaction ) {
         my $rolled_back;
@@ -322,8 +333,8 @@ sub commit_sql {
             for my $values ( @$rows_to_execute ) {
                 $sth->execute( @$values );
             }
-            my $row_count   = $stmt_type eq 'Insert' ? @$rows_to_execute : $sth->rows;
-            my $commit_ok = sprintf qq(  %s %d "%s"), 'COMMIT', $row_count, $stmt_type; # show count of affected rows
+            my $row_count = $stmt_type eq 'Insert' ? @$rows_to_execute : $sth->rows;
+            my $commit_ok = sprintf qq(  %s %d "%s"), 'COMMIT', $row_count, $stmt_type;
             $ax->print_sql( $sql, $stmt_typeS );
             # Choose
             my $choice = $stmt_v->choose(
@@ -348,6 +359,7 @@ sub commit_sql {
         return 1;
     }
     else {
+#
         my $row_count;
         if ( $stmt_type eq 'Insert' ) {
             $row_count = @$rows_to_execute;
@@ -358,6 +370,7 @@ sub commit_sql {
             $count_stmt .= $sql->{where_stmt};
             ( $row_count ) = $dbh->selectrow_array( $count_stmt, undef, @{$sql->{where_args}} );
         }
+#
         my $commit_ok = sprintf qq(  %s %d "%s"), 'EXECUTE', $row_count, $stmt_type;
         $ax->print_sql( $sql, $stmt_typeS ); #
         # Choose
@@ -387,13 +400,12 @@ sub __table_write_access {
     my ( $sf, $sql, $stmt_type ) = @_;
     my @stmt_types;
     if ( ! $sf->{i}{multi_tbl} ) {
-        @stmt_types = ( 'Insert', 'Update', 'Delete' );
+        push @stmt_types, 'Insert' if $sf->{o}{G}{insert_ok};
+        push @stmt_types, 'Update' if $sf->{o}{G}{update_ok};
+        push @stmt_types, 'Delete' if $sf->{o}{G}{delete_ok};
     }
     elsif ( $sf->{i}{multi_tbl} eq 'join' && $sf->{i}{driver} eq 'mysql' ) {
-        @stmt_types = ( 'Update' );
-    }
-    else {
-        @stmt_types = ();
+        push @stmt_types, 'Update' if $sf->{o}{G}{update_ok};
     }
     if ( ! @stmt_types ) {
         return $stmt_type; #
